<?php
/*
Plugin Name: Clean Duplicator
Plugin URI: https://oigorribeiro.com.br/plugins-wp/clean-duplicator/
Description: Duplique o que desejar sem deixar seu WordPress pesado ou poluído.
Version: 1.0
Author: Igor Ribeiro
Author URI: https://oigorribeiro.com.br/
License: GPL2
*/

if (!defined('ABSPATH')) {
    exit;
}

function cd_add_duplicate_link($actions, $post)
{
    if (current_user_can('edit_posts')) {
        $url = wp_nonce_url('admin.php?action=cd_duplicate_post&post=' . $post->ID, basename(__FILE__), 'duplicate_nonce');
        $actions['duplicate'] = "<a href=\"$url\" title=\"Duplicar este item\" rel=\"permalink\">Duplicar</a>";
    }
    return $actions;
}
add_filter('post_row_actions', 'cd_add_duplicate_link', 10, 2);
add_filter('page_row_actions', 'cd_add_duplicate_link', 10, 2);

function cd_duplicate_post_as_draft()
{
    if (!isset($_GET['post'], $_GET['duplicate_nonce']) || !wp_verify_nonce($_GET['duplicate_nonce'], basename(__FILE__))) {
        return;
    }

    $post_id = absint($_GET['post']);
    $post = get_post($post_id);

    if ($post) {
        $new_post = array(
            'post_title'   => $post->post_title . ' (Cópia)',
            'post_content' => $post->post_content,
            'post_status'  => 'draft',
            'post_type'    => $post->post_type,
            'post_author'  => $post->post_author,
            'post_excerpt' => $post->post_excerpt,
            'post_parent'  => $post->post_parent,
            'post_password' => $post->post_password,
            'comment_status' => $post->comment_status,
            'ping_status'    => $post->ping_status,
        );

        $new_post_id = wp_insert_post($new_post);

        if ($new_post_id) {
            $taxonomies = get_object_taxonomies($post->post_type);
            foreach ($taxonomies as $taxonomy) {
                $post_terms = wp_get_object_terms($post_id, $taxonomy, array('fields' => 'slugs'));
                wp_set_object_terms($new_post_id, $post_terms, $taxonomy, false);
            }

            $post_meta = get_post_meta($post_id);
            foreach ($post_meta as $meta_key => $meta_values) {
                foreach ($meta_values as $meta_value) {
                    update_post_meta($new_post_id, $meta_key, maybe_unserialize($meta_value));
                }
            }

            wp_redirect(admin_url('edit.php?post_type=' . $post->post_type));
            exit;
        }
    }

    wp_die('Post creation failed, could not find original post: ' . $post_id);
}
add_action('admin_action_cd_duplicate_post', 'cd_duplicate_post_as_draft');

function cd_add_duplicate_category_link($actions, $tag)
{
    if (current_user_can('manage_categories')) {
        $url = wp_nonce_url('admin.php?action=cd_duplicate_category&tag_ID=' . $tag->term_id, basename(__FILE__), 'duplicate_nonce');
        $actions['duplicate'] = "<a href=\"$url\" title=\"Duplicar esta categoria\" rel=\"permalink\">Duplicar</a>";
    }
    return $actions;
}
add_filter('category_row_actions', 'cd_add_duplicate_category_link', 10, 2);

function cd_duplicate_category_as_draft()
{
    if (!isset($_GET['tag_ID'], $_GET['duplicate_nonce']) || !wp_verify_nonce($_GET['duplicate_nonce'], basename(__FILE__))) {
        return;
    }

    $term_id = absint($_GET['tag_ID']);
    $term = get_term($term_id);

    if ($term) {
        $new_term = wp_insert_term($term->name . ' (Cópia)', 'category', array(
            'description' => $term->description,
            'slug'        => $term->slug . '-copia',
            'parent'      => $term->parent
        ));

        if (!is_wp_error($new_term)) {
            wp_redirect(admin_url('edit-tags.php?taxonomy=category'));
            exit;
        } else {
            wp_die('Category creation failed, could not create duplicate category.');
        }
    }

    wp_die('Category creation failed, could not find original category: ' . $term_id);
}
add_action('admin_action_cd_duplicate_category', 'cd_duplicate_category_as_draft');
